﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Globalization;
using System.IO;
using System.Windows.Media;

using MindFusion.Spreadsheet.Wpf;
using MindFusion.Spreadsheet.Wpf.StandardForms;

namespace BudgetAllocation
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            //add a new sheet to the workbook
            var activeSheet = workbook.Worksheets.Add();
            workbookView.ActiveWorksheet = activeSheet;
            activeSheet.BeginInit();

            //create a global styling for the whole sheet
            var globalStyle = activeSheet.CellRanges[0, 0, activeSheet.Columns.Count - 1, activeSheet.Rows.Count - 1].Style;
            globalStyle.FontName = "Malgun Gothic";
            globalStyle.FontSize = 8;
            globalStyle.HorizontalAlignment = MindFusion.Spreadsheet.Wpf.HorizontalAlignment.Center;
   
            //edit the data and style the first header row
            var heading = activeSheet.CellRanges["A2:G2"];
            heading.Merge();
            activeSheet.Cells["A2"].Data = "비율로서의 자금 분배"; // "Funds Distribution as a Ratio";
            var headingStyle = heading.Style;
            headingStyle.FontBold = true;
            headingStyle.VerticalAlignment = MindFusion.Spreadsheet.Wpf.VerticalAlignment.Middle;
            headingStyle.PaddingLeft = "5pt";
            headingStyle.BorderBottomBrush = Brushes.Gray;
            headingStyle.BorderBottomSize = "1pt";
            headingStyle.Background = new SolidColorBrush(Color.FromRgb(220, 220, 220));

            //add data to cell A3 and style it
            activeSheet.Cells["A3"].Data = "기간"; // "Period";
            activeSheet.Cells["A3"].Style.FontBold = true;
            activeSheet.Cells["A3"].Style.Background = new SolidColorBrush(Color.FromRgb(240, 240, 240));
            activeSheet.Cells["A3"].Style.BorderBottomBrush = new SolidColorBrush(Color.FromRgb(220, 220, 220));
            activeSheet.Cells["A3"].Style.BorderRightBrush = new SolidColorBrush(Color.FromRgb(220, 220, 220));

            //add data to cell A4 and style it
            activeSheet.Cells["A4"].Data = "엔지니어"; //""Engineers";
            activeSheet.Cells["A4"].Style.FontBold = true;
            activeSheet.Cells["A4"].Style.Background = new SolidColorBrush(Color.FromRgb(240, 240, 240));
            activeSheet.Cells["A4"].Style.BorderBottomBrush = new SolidColorBrush(Color.FromRgb(220, 220, 220));
            activeSheet.Cells["A4"].Style.BorderRightBrush = new SolidColorBrush(Color.FromRgb(220, 220, 220));

            //add data to cell A5 and style it
            activeSheet.Cells["A5"].Data = "마케팅"; // "Marketing";
            activeSheet.Cells["A5"].Style.FontBold = true;
            activeSheet.Cells["A5"].Style.Background = new SolidColorBrush(Color.FromRgb(240, 240, 240));
            activeSheet.Cells["A5"].Style.BorderBottomBrush = new SolidColorBrush(Color.FromRgb(220, 220, 220));
            activeSheet.Cells["A5"].Style.BorderRightBrush = new SolidColorBrush(Color.FromRgb(220, 220, 220));

            //add data to cell A6 and style it
            activeSheet.Cells["A6"].Data = "판매"; // "Sales";
            activeSheet.Cells["A6"].Style.FontBold = true;
            activeSheet.Cells["A6"].Style.Background = new SolidColorBrush(Color.FromRgb(240, 240, 240));
            activeSheet.Cells["A6"].Style.BorderRightBrush = new SolidColorBrush(Color.FromRgb(220, 220, 220));

            //add data to cell A7 and style it
            activeSheet.Cells["A7"].Data = "합계";// "Total";
            activeSheet.Cells["A7"].Style.FontBold = true;
            activeSheet.Cells["A7"].Style.Background = new SolidColorBrush(Color.FromRgb(240, 240, 240));
            activeSheet.Cells["A7"].Style.BorderBottomBrush = new SolidColorBrush(Color.FromRgb(220, 220, 220));
            activeSheet.Cells["A7"].Style.BorderRightBrush = new SolidColorBrush(Color.FromRgb(220, 220, 220));

            //add data to the row of cells from B3 to F3
            activeSheet.Cells["B3"].Data = "Q1";
            activeSheet.Cells["C3"].Data = "Q2";
            activeSheet.Cells["D3"].Data = "Q3";
            activeSheet.Cells["E3"].Data = "Q4";
            activeSheet.Cells["F3"].Data = "년"; // "Year";

            //add data to the row of cells from B4 to F4
            activeSheet.Cells["B4"].Data = "43";
            activeSheet.Cells["C4"].Data = "40";
            activeSheet.Cells["D4"].Data = "41";
            activeSheet.Cells["E4"].Data = "47";
            activeSheet.Cells["F4"].Data = "=SUM(B4:E4)";

            //set the data for cells B5 to E5
            activeSheet.Cells["B5"].Data = "23";
            activeSheet.Cells["C5"].Data = "25";
            activeSheet.Cells["D5"].Data = "28";
            activeSheet.Cells["E5"].Data = "17";
            activeSheet.Cells["E5"].Style.Background = Brushes.LightBlue;
            
            //add annotation
            activeSheet.Cells["E5"].SetAnnotation("마케팅 예산 절감" /*"Marketing budget was cut down"*/);
            // Customize the annotation's appearance
            activeSheet.Cells["E5"].Annotation.CellAnnotation.BackBrush = Brushes.AliceBlue;
            activeSheet.Cells["F5"].Data = "=SUM(B4:B6)";

            //add data to cells B6 to F6
            activeSheet.Cells["B6"].Data = "34";
            activeSheet.Cells["C6"].Data = "35";
            activeSheet.Cells["D6"].Data = "31";
            activeSheet.Cells["E6"].Data = "36";
            activeSheet.Cells["F6"].Data = "=SUM(B6:E6)";

            //specify formulas for cells B7 to F7 and make their text bold
            activeSheet.Cells["B7"].Data = "=SUM(B4:B6)";
            activeSheet.Cells["B7"].Style.FontBold = true;
            activeSheet.Cells["C7"].Data = "=SUM(C4:C6)";
            activeSheet.Cells["C7"].Style.FontBold = true;
            activeSheet.Cells["D7"].Data = "=SUM(D4:D6)";
            activeSheet.Cells["D7"].Style.FontBold = true;
            activeSheet.Cells["E7"].Data = "=SUM(E4:E6)";
            activeSheet.Cells["E7"].Style.FontBold = true;
            activeSheet.Cells["F7"].Data = "=SUM(F4:F6)";
            activeSheet.Cells["F7"].Style.FontBold = true;

            activeSheet.CellRanges["A7:G7"].Style.BorderTopBrush = Brushes.Gray;

            //increase row height
            activeSheet.Rows[1, 20].Height = "20pt";

            var file = @"../../Localization/Localization.KO.xml";
            if (file != null && File.Exists(file))
                workbook.SetLocalizationInfo(file);

            workbook.Locale = new CultureInfo("ko-KR");           

            //apply stling on the row with sales data
            var salesStyle = activeSheet.CellRanges[1, 5, 4, 5].Style;
            salesStyle.FontBold = true;
            salesStyle.Format = "#,##0.00;(#,##0.00)";

            // Set a conditional format
            var format1 = salesStyle.ConditionalFormats.Add();
            format1.Type = ConditionalFormatType.CellValue;
            format1.Operator = ComparisonOperator.LessThan;
            format1.First = "35";
            format1.Style.Background = new SolidColorBrush(Color.FromArgb(255, 255, 120, 85));
            format1.Style.Background.Freeze();

            activeSheet.EndInit();

        }

        //handle clicks on the context menu
        private void ContextMenu_Click(object sender, RoutedEventArgs e)
        {
            var menu = sender as ContextMenu;
            var index = menu.Items.IndexOf(e.OriginalSource);

            switch (index)
            {
                case 0:
                    {
                        new DeleteCellsForm(workbook).ShowDialog();
                        break;
                    }
                case 1:
                    {
                        new InsertCellsForm(workbook).ShowDialog();
                        break;
                    }
                case 2:
                    {
                        new WorksheetRenameForm(workbook, "New name").ShowDialog();
                        break;
                    }
            }


        }
    }
}
